@@ -1,4 +1,8 @@
-"""Argyris elements on simplices."""
+"""Argyris elements on simplices.
+
+This element's definition appears in https://doi.org/10.1017/S000192400008489X
+(Arygris, Fried, Scharpf, 1968)
+"""
 
 from ..core.finite_element import FiniteElement
 from ..core.polynomials import polynomial_set
@@ -11,7 +15,7 @@ from ..core.symbolic import sym_sum
 class Argyris(FiniteElement):
     """Argyris finite element."""
 
-    def __init__(self, reference, order):
+    def __init__(self, reference, order, variant):
         from symfem import create_reference
         assert order == 5
         assert reference.name == "triangle"
