@@ -1,4 +1,8 @@
-"""Brezzi-Douglas-Marini elements on simplices."""
+"""Brezzi-Douglas-Marini elements on simplices.
+
+This element's definition appears in https://doi.org/10.1007/BF01389710
+(Brezzi, Douglas, Marini, 1985)
+"""
 
 from ..core.finite_element import FiniteElement
 from ..core.moments import make_integral_moment_dofs
@@ -11,13 +15,14 @@ from .nedelec import NedelecFirstKind
 class BDM(FiniteElement):
     """Brezzi-Douglas-Marini Hdiv finite element."""
 
-    def __init__(self, reference, order):
+    def __init__(self, reference, order, variant):
         poly = polynomial_set(reference.tdim, reference.tdim, order)
 
         dofs = make_integral_moment_dofs(
             reference,
             facets=(NormalIntegralMoment, DiscontinuousLagrange, order),
             cells=(IntegralMoment, NedelecFirstKind, order - 1),
+            variant=variant
         )
 
         super().__init__(reference, order, poly, dofs, reference.tdim, reference.tdim)
