@@ -1,4 +1,8 @@
-"""Morley elements on simplices."""
+"""Morley elements on simplices.
+
+This element's definition appears in https://doi.org/10.1017/S0001925900004546
+(Morley, 1968)
+"""
 
 from ..core.finite_element import FiniteElement
 from ..core.polynomials import polynomial_set
@@ -9,7 +13,7 @@ from ..core.symbolic import sym_sum
 class Morley(FiniteElement):
     """Morley finite element."""
 
-    def __init__(self, reference, order):
+    def __init__(self, reference, order, variant):
         from symfem import create_reference
         assert order == 2
         assert reference.name == "triangle"
