@@ -1,4 +1,9 @@
-"""Mardal-Tai-Winther elements on simplices."""
+"""Mardal-Tai-Winther elements on simplices.
+
+This element's definition appears in https://doi.org/10.1137/S0036142901383910
+(Mardal, Tai, Winther, 2002)
+and https://doi.org/10.1007/s10092-006-0124-6 (Tail, Mardal, 2006)
+"""
 
 from ..core.finite_element import FiniteElement
 from ..core.moments import make_integral_moment_dofs
@@ -13,22 +18,28 @@ from .nedelec import NedelecFirstKind
 class MardalTaiWinther(FiniteElement):
     """Mardal-Tai-Winther Hdiv finite element."""
 
-    def __init__(self, reference, order):
+    def __init__(self, reference, order, variant):
         assert order == 3
 
         dofs = make_integral_moment_dofs(
-            reference, facets=(NormalIntegralMoment, DiscontinuousLagrange, 1))
+            reference, facets=(NormalIntegralMoment, DiscontinuousLagrange, 1),
+            variant=variant)
 
         if reference.name == "triangle":
             poly = [(one, zero), (x[0], zero), (x[1], zero),
                     (zero, one), (zero, x[0]), (zero, x[1]),
-                    (5 * x[0] ** 2 + 16 * x[0] * x[1], -10 * x[0] * x[1] - 8 * x[1] ** 2),
-                    (-x[1] * x[0] ** 2 / 2 - 9 * x[1] ** 2 * x[0] / 7 + 170 * 3 * x[1] ** 2 * x[0] / (27 * 28) - 170 * 7 * x[0] ** 3 / (20 * 27 * 28),  # noqa: E501
-                     3 * x[1] ** 3 / 7 + x[0] * x[1] ** 2 / 2 - 170 * x[1] ** 3 / (27 * 28) + 170 * 21 * x[0] ** 2 * x[1] / (20 * 27 * 28)),  # noqa: E501
-                    (-x[1] * x[0] ** 2 / 2 - 9 * x[1] ** 2 * x[0] / 7 - 17 * x[0] ** 2 / (28 * 4),
-                     3 * x[1] ** 3 / 7 + x[0] * x[1] ** 2 / 2 + 2 * 17 * x[0] * x[1] / (28 * 4))]
+                    # (x**2 + 2*x*y, -2*x*y - y**2)
+                    (x[0] ** 2 + 2 * x[0] * x[1],
+                     -2 * x[0] * x[1] - x[1] ** 2),
+                    # (-x**3 + 2*x**2 + 3*x*y**2, 3*x**2*y - 4*x*y - y**3)
+                    (-x[0] ** 3 + 2 * x[0] ** 2 + 3 * x[0] * x[1] ** 2,
+                     3 * x[0] ** 2 * x[1] - 4 * x[0] * x[1] - x[1] ** 3),
+                    # (2*x**2*y + x**2 + 3*x*y**2, -2*x*y**2 - 2*x*y - y**3)
+                    (2 * x[0] ** 2 * x[1] + x[0] ** 2 + 3 * x[0] * x[1] ** 2,
+                     -2 * x[0] * x[1] ** 2 - 2 * x[0] * x[1] - x[1] ** 3)]
             dofs += make_integral_moment_dofs(
-                reference, facets=(TangentIntegralMoment, DiscontinuousLagrange, 0))
+                reference, facets=(TangentIntegralMoment, DiscontinuousLagrange, 0),
+                variant=variant)
         else:
             assert reference.name == "tetrahedron"
 
@@ -38,7 +49,8 @@ class MardalTaiWinther(FiniteElement):
                                        for i in p)))
 
             dofs += make_integral_moment_dofs(
-                reference, facets=(IntegralMoment, NedelecFirstKind, 1))
+                reference, facets=(IntegralMoment, NedelecFirstKind, 1),
+                variant=variant)
 
         super().__init__(reference, order, poly, dofs, reference.tdim, reference.tdim)
 
@@ -47,4 +59,4 @@ class MardalTaiWinther(FiniteElement):
     min_order = 3
     max_order = 3
     mapping = "contravariant"
-    continuity = "L2"
+    continuity = "H(div)"
