@@ -1,4 +1,9 @@
-"""Regge elements on simplices."""
+"""Regge elements on simplices.
+
+This element's definition appears in https://doi.org/10.1007/BF02733251
+(Regge, 1961) and https://doi.org/10.1007/s00211-011-0394-z
+(Christiansen, 2011)
+"""
 
 import sympy
 from itertools import product
@@ -10,7 +15,7 @@ from ..core.functionals import PointInnerProduct
 class Regge(FiniteElement):
     """A Regge element."""
 
-    def __init__(self, reference, order):
+    def __init__(self, reference, order, variant):
         from symfem import create_reference
         assert reference.name in ["triangle", "tetrahedron"]
         if reference.tdim == 2:
@@ -35,7 +40,7 @@ class Regge(FiniteElement):
                                 tuple(o + sum(sympy.Rational(a[j] * b, order + 2)
                                               for a, b in zip(entity.axes, i[::-1]))
                                       for j, o in enumerate(entity.origin)),
-                                tangent, entity=(edim, e_n)))
+                                tangent, tangent, entity=(edim, e_n)))
 
         super().__init__(reference, order, poly, dofs, reference.tdim, reference.tdim ** 2,
                          (reference.tdim, reference.tdim))
