@@ -1,4 +1,8 @@
-"""Raviart-Thomas elements on simplices."""
+"""Raviart-Thomas elements on simplices.
+
+This element's definition appears in https://doi.org/10.1007/BF01396415
+(Nedelec, 1980)
+"""
 
 from ..core.finite_element import FiniteElement
 from ..core.moments import make_integral_moment_dofs
@@ -10,7 +14,7 @@ from .lagrange import DiscontinuousLagrange, VectorDiscontinuousLagrange
 class RaviartThomas(FiniteElement):
     """Raviart-Thomas Hdiv finite element."""
 
-    def __init__(self, reference, order):
+    def __init__(self, reference, order, variant):
         poly = polynomial_set(reference.tdim, reference.tdim, order - 1)
         poly += Hdiv_polynomials(reference.tdim, reference.tdim, order)
 
@@ -18,6 +22,7 @@ class RaviartThomas(FiniteElement):
             reference,
             facets=(NormalIntegralMoment, DiscontinuousLagrange, order - 1),
             cells=(IntegralMoment, VectorDiscontinuousLagrange, order - 2),
+            variant=variant
         )
 
         super().__init__(reference, order, poly, dofs, reference.tdim, reference.tdim)
